function [] = analysis(fileID,filename,filepath)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function generates the neccessary session file commands to create  %
% a keyword file from a database in PATRAN.                               %
%                                                                         %
%                                                                         %
% Written by Halvor L. Aga as part of the work concerning                 %
% "Assessement if structural requirements related to LNG fuel tanks."     %
% Deadline 10. June 2013                                                  %
% Has been made by modification of recorded .ses commands in PATRAN.      %
%                                                                         %
% Build-up:                                                               %
% 1. Analysis commands (Copied directly from a recorded PATRAN session    %
%    file)                                                                %
%                                                                         %
% Input:                                                                  %
%       fileID: The file ID of the file for storage of commands, file must%
%               be open.                                                  %
%       filename: Name of the file, same for .ses and db. file            %
%       filepath: The placement of the database file                      %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Writing commands for generation of keyword file
fprintf(fileID,'loadsbcs_eval_all(  )\n');
fprintf(fileID,'jobfile.open( "%s", "ANALYZE NO JOBFILE" )\n',filename);
fprintf(fileID,...
'jobfile.create_param( "version_opt", 0, 0., "LS-930", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "sep_mesh", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "sep_mat", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "label_file", 0, 0., "*.sif", 4 )\n');
fprintf(fileID,'jobfile.create_param( "list_file", 0, 0., "", 1 )\n');
fprintf(fileID,'jobfile.create_param( "cpu_time_limit", 0, 0., "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "termination_step", 0, 0., "", 1 )\n');
fprintf(fileID,...
    'jobfile.create_param( "termination_time", 0, 0., "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "time_step_ratio_limit", 0, 0., "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "energy_ratio_limit", 0, 0., "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "mass_ratio_limit", 0, 0., "", 3 )\n');
fprintf(fileID,'jobfile.create_param( "time_size_calc_basis", 0,@\n');
fprintf(fileID,'0., "Area/Edge", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "initial_time_step", 0, 0., "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "step_scale_factor", 0, 0.89999998, "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "step_size_for_mass_scale", 0, 0., "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "shell_minimum_time_step", 0, 0., "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "load_curve_max_time_step", 0, 0., "", 1 )\n');
fprintf(fileID,...
    'jobfile.create_param( "erosion_flag", 0, 0., "OFF", 4 )\n');
fprintf(fileID,'jobfile.create_param( "mass_scaling_first_step",@\n');
fprintf(fileID,'0, 0., "OFF", 4 )\n');
fprintf(fileID,'jobfile.create_param( "Number_of_cpus", 1, 0., "", 1 )\n');
fprintf(fileID,...
    'jobfile.create_param( "One_rhs_only", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "Consistency_flg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "parallel_force", 0, 0., "OFF", 4 )\n');
fprintf(fileID,'jobfile.create_param( "optmenu_relaxation", 0, 0.,@\n');
fprintf(fileID,'"None.Active", 4 )\n');
fprintf(fileID,'jobfile.create_param( "geometry_file", 0, 0., "", 4 )\n');
fprintf(fileID,'jobfile.create_param( "relax_termination_time", 0,@\n');
fprintf(fileID,'1E+030, "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "con_tolerance", 0, 0.001, "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "Iterations_checks", 250, 0., "", 1 )\n');
fprintf(fileID,...
    'jobfile.create_param( "auto_control", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "papadrakakis", 0, 0.039999999, "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "Relaxation_Factor", 0, 0.995, "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "Time_scale_Factor", 0, 0.89999998, "", 3 )\n');
fprintf(fileID,'jobfile.create_param( "global_damping_curve", 0, 0., @\n');
fprintf(fileID,'"f:ouatiafltlak", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "system_damping_constant", 0, 0., "", 3 )\n');
fprintf(fileID,'jobfile.create_param( "linear_viscosity_@\n');
fprintf(fileID,'coefficient", 0, 0.059999999, "", 3 )\n');
fprintf(fileID,'jobfile.create_param( "quadratic_viscosity_@\n');
fprintf(fileID,'coefficient", 0, 1.5, "", 3 )\n');
fprintf(fileID,'jobfile.create_param( "hourglass_viscosity_@\n');
fprintf(fileID,'type", 0, 0., "LS_DYNA", 4 )\n');
fprintf(fileID,'jobfile.create_param( "hourglass_viscosity_@\n');
fprintf(fileID,'coefficient", 0, 0.1, "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "hourglass_energy_calc", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "stonewall_energy_diss", 0, 0., "ON", 4 )\n');
fprintf(fileID,'jobfile.create_param( "sliding_int_energy_diss"@\n');
fprintf(fileID,', 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "rayleigh_energy_diss", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "Warning_angle_warpage", 0, 20., "", 3 )\n');
fprintf(fileID,'jobfile.create_param( "Treat_degen_quads_as_tris", @\n');
fprintf(fileID,'0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "shell_theory", 0, 0., "Belytschko", 4 )\n');
fprintf(fileID,'jobfile.create_param( "warping_stiffness", 0, 0., @\n');
fprintf(fileID,'"Belytschko-Tsay", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "normal_update", 0, 0., "Each Cycle", 4 )\n');
fprintf(fileID,'jobfile.create_param( "update_option", -1, 0., "", 1 )\n');
fprintf(fileID,...
    'jobfile.create_param( "update_shell_thick", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "plastics_method", 0, 0., "Secant", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "consider_shell_thickness", 0, 0.,  @\n');
fprintf(fileID,'"Thickness not considered", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "check_penetration", 0, 0., "ON", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "max_check_multiplier", 0, 4., "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "step_bet_search", 10, 0., "", 1 )\n');
fprintf(fileID,...
    'jobfile.create_param( "search_old_surface", 0, 0., "OFF", 4 )\n');
fprintf(fileID,'jobfile.create_param( "stiffness_value", 0, 0., @\n');
fprintf(fileID,'"Min. of Master & Slave", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "scale_interface", 0, 0.1, "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "scale_rigid_wall", 0, 0., "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "shell_thick_include", 0, 0., "OFF", 4 )\n');
fprintf(fileID,'jobfile.create_param( "auto_reorientation", 0, 0., @\n');
fprintf(fileID,'"Active for Automated", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "control_subroutine", 0, 0., "", 1 )\n');
fprintf(fileID,...
    'jobfile.create_param( "friction_subroutine", 0, 0., "", 1 )\n');
fprintf(fileID,...
    'jobfile.create_param( "bin_state_time_int", 0, 0., "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "excl_damp_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "local_coord_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "one_plot_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "elim_rigid_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "output_hglass_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "output_time_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "num_beam_int_dbox", 0, 0., "", 1 )\n');
fprintf(fileID,...
    'jobfile.create_param( "inc_surf_strain_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "excl_sh_tensor_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "excl_sh_strain_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "excl_sh_res_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "excl_int_energy_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "num_var_sol_dbox", 0, 0., "", 1 )\n');
fprintf(fileID,...
    'jobfile.create_param( "num_var_sh_dbox", 0, 0., "", 1 )\n');
fprintf(fileID,...
    'jobfile.create_param( "num_sh_int_dbox", 0, 0., "", 1 )\n');
fprintf(fileID,...
    'jobfile.create_param( "bin_history_time_int", 0, 0., "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "inc_nodes_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "inc_beams_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "inc_shell_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "inc_solid_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "inc_th_sh_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "inc_extra_tg", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "Pri_During_Input", 0, 0., "ON", 4 )\n');
fprintf(fileID,'jobfile.create_param( "Echo_File_Options", 0, 0., @\n');
fprintf(fileID,'"Suppress Both", 4 )\n');
fprintf(fileID,'jobfile.create_param( "Velocities", 0, 0., "OFF", 4 )\n');
fprintf(fileID,'jobfile.create_param( "Update_Beam", 0, 0., "OFF", 4 )\n');
fprintf(fileID,'jobfile.create_param( "Interface_File", 0, 0., "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "Interface_File_Name", 0, 0., "INTFOR", 4 )\n');
fprintf(fileID,'jobfile.create_param( "Time_Step", 0, 0., "ON", 4 )\n');
fprintf(fileID,'jobfile.create_param( "Time_Interval", 0, 0., "", 1 )\n');
fprintf(fileID,...
    'jobfile.create_param( "Tolerance_Status", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "Tolerance_Value", 0, 0., "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "viewport", 0, 0., "default_viewport", 4 )\n');
fprintf(fileID,'jobfile.create_param( "datbox_groupname", 0, 0., @\n');
fprintf(fileID,'"default_group", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "tranlational", 0, 0., "<0,0,0>", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "rotational", 0, 0., "<0,0,0>", 4 )\n');
fprintf(fileID,'jobfile.create_param( "loadcase_for_analysis", 0, @\n');
fprintf(fileID,'0., "Default", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "set_node_opt", 0, 0., "YES", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "set_beam_opt", 0, 0., "YES", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "set_discrete_opt", 0, 0., "YES", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "set_shell_opt", 0, 0., "YES", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "set_solid_opt", 0, 0., "YES", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "set_tshell_opt", 0, 0., "YES", 4 )\n');
fprintf(fileID,'jobfile.create_param( "w_db_node", 5, 0., "", 1 )\n');
fprintf(fileID,'jobfile.create_param( "w_db_beam", 5, 0., "", 1 )\n');
fprintf(fileID,'jobfile.create_param( "w_db_discrete", 5, 0., "", 1 )\n');
fprintf(fileID,'jobfile.create_param( "w_db_shell", 5, 0., "", 1 )\n');
fprintf(fileID,'jobfile.create_param( "w_db_solid", 5, 0., "", 1 )\n');
fprintf(fileID,'jobfile.create_param( "w_db_tshell", 5, 0., "", 1 )\n');
fprintf(fileID,...
    'jobfile.create_param( "all_groups_in_db_id", 1, 0., "", 1 )\n');
fprintf(fileID,'jobfile.create_param( "all_groups_in_db_id_1", 0, @\n');
fprintf(fileID,'0., "default_group", 101 )\n');
fprintf(fileID,'jobfile.create_param( "setcard_fullmodel_group_id", @\n');
fprintf(fileID,'1, 0., "", 1 )\n');
fprintf(fileID,'jobfile.create_param( "setcard_fullmodel_group_id_1",@\n');
fprintf(fileID,' 0, 0., "default_group",  @\n');
fprintf(fileID,'101 )\n');
fprintf(fileID,...
    'jobfile.create_param( "factor_length_from_MADYMO", 0, 1., "", 3 )\n');
fprintf(fileID,'jobfile.create_param( "factor_on_time_from_MADYMO", @\n');
fprintf(fileID,'0, 1., "", 3 )\n');
fprintf(fileID,'jobfile.create_param( "factor_on_force_from_MADYMO", @\n');
fprintf(fileID,'0, 1., "", 3 )\n');
fprintf(fileID,'jobfile.create_param( "Wait_time_as_MADYMO_computes"@\n');
fprintf(fileID,', 0, 0., "", 3 )\n');
fprintf(fileID,...
    'jobfile.create_param( "Flip_X_coord_of_MADYMO", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "Flip_Y_coord_of_MADYMO", 0, 0., "OFF", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "Flip_Z_coord_of_MADYMO", 0, 0., "OFF", 4 )\n');
fprintf(fileID,'jobfile.create_param( @\n');
fprintf(fileID,'"Num_Dyna_steps_per_MADYMO_step", 1, 0., "", 1 )\n');
fprintf(fileID,'jobfile.create_param( "filename_interface", 0, 0.,  @\n');
fprintf(fileID,'"Default_interfacefile.isf1", 4 )\n');
fprintf(fileID,...
    'jobfile.create_param( "restart_label_file", 0, 0., "", 4 )\n');
fprintf(fileID,'jobfile.create_param( "DTIwrite_switch_id",@\n');
fprintf(fileID,' 0, 0., "End Deck", 4 )\n');
fprintf(fileID,'jobfile.create_param( "DTIdirect_text_toggle_id",@\n');
fprintf(fileID,' 0, 0., "OFF", 4 )\n');
fprintf(fileID,'jobfile.close(  )\n');
fprintf(fileID,'uil_file_close.go(  )\n');
fprintf(fileID,'sys_library( "add", "lsdyna3d.plb" )\n');
fprintf(fileID,...
    'lsdyna3d_spawn_generic( "pat3lsdyna", " -d %s" // @\n',filepath);
fprintf(fileID,'"\\%s.db -j %s", TRUE )\n',filename,filename);

end