function [sc] = bulb(fileID,R1,R2,L,zoff,yoff,xoff,sc,esize)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function generates necessary commands for generation of a bow in PATRAN    %
%                                                                                 %
% Written by Halvor L. Aga as part of the work concerning                         %
% "Assessement if structural requirements related to LNG fuel tanks."             %
% Deadline 10. June 2013                                                          %
% Has been made by modification of recorded .ses commands in PATRAN.              %
%                                                                                 %
% Input:                                                                          %
%        fileID - identification key for keyword file                             % 
%        Scantlings (R1 - Radius at striking end of the bow, R2 - Radius at       %
%                    following end of bow, L - Length of bow)                     %
%        Offset from origo (zoff,toff,xoff)                                       %
%        sc     - surface counter                                                 %
%        esize  - mesh size on the bulb                                           % 
%                                                                                 %
% Output: sc    - surface counter                                                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% Checking if length of bow and radius given as input are compatible.
if L>R1
    % Printing commands for point generation
    fprintf(fileID,'STRING asm_create_grid_xyz_created_ids[VIRTUAL]\n');
    fprintf(fileID,'asm_const_grid_xyz( "1", "[%d %d %d]", @\n',xoff,yoff,zoff);
    fprintf(fileID,'"Coord 0", asm_create_grid_xyz_created_ids )\n');
    fprintf(fileID,'asm_const_grid_xyz( "2", "[%d %f %f]", @\n',xoff,-R1-yoff,-R1+zoff);
    fprintf(fileID,'"Coord 0",  asm_create_grid_xyz_created_ids )\n');
    fprintf(fileID,'asm_const_grid_xyz( "3", "[%d %f %f]",  @\n',xoff,-L-yoff,-R2+zoff);
    fprintf(fileID,'"Coord 0", asm_create_grid_xyz_created_ids )\n');
    fprintf(fileID,'asm_const_grid_xyz( "4", "[%d %f %d]",  @\n',xoff,-L-yoff,zoff);
    fprintf(fileID,'"Coord 0", asm_create_grid_xyz_created_ids )\n');

    % Printing commands for curve generation
    fprintf(fileID,'STRING sgm_create_curve_2d_created_ids[VIRTUAL]\n');
    fprintf(fileID,'sgm_const_curve_2d_arc2point_v2( "1", 2, %f, FALSE, TRUE, 1,  @\n',R1);
    fprintf(fileID,'"Coord 0.1", "", "point 1", "point 2", FALSE,@\n');
    fprintf(fileID,'sgm_create_curve_2d_created_ids )\n');
    fprintf(fileID,'STRING asm_line_2point_created_ids[VIRTUAL]\n');
    fprintf(fileID,'asm_const_line_2point( "2", "point 2", "point 3", 0, "", 50., 1,  @\n');
    fprintf(fileID,'asm_line_2point_created_ids )\n');
    fprintf(fileID,'asm_const_line_2point( "4", "point 4", "point 1", 0, "", 50., 1,  @\n');
    fprintf(fileID,'asm_line_2point_created_ids )\n');
    
    
    sc = sc+1;
    
    % Printing commands for solid generation
    fprintf(fileID,'STRING sgm_sweep_surface_r_created_ids[VIRTUAL]\n');
    fprintf(fileID,'sgm_const_surface_revolve( "%d", "Construct CurvePointTangent(Evaluate Geometry(Curve 4))(Evaluate Geometry(Point 1))", 360., 0., "Coord 0", "Curve 1:2", sgm_sweep_surface_r_created_ids )\n',sc);
    % Printing commands for material generation
    fprintf(fileID,'material.create( "Analysis code ID", 10001, "Analysis type ID", 1,  @\n');
    fprintf(fileID,'"Rigid_steel", 0, " ", "Isotropic", 1,  @\n');
    fprintf(fileID,'"Directionality", 1, "Linearity", 11001, "Homogeneous", 0, "Rigid", 11001,  @\n');
    fprintf(fileID,'"Model Options & IDs", ["Material Type 20", "", "", "", ""], [11006, 0, 0, 0,  @\n');
    fprintf(fileID,'0], "Active Flag", 1, "Create", 10, "External Flag", FALSE, "Property IDs", [ @\n');
    fprintf(fileID,'"Density", "Elastic Modulus", "Poisson Ratio"], [16, 2, 5, 0],  @\n');
    fprintf(fileID,'"Property Values", ["7.85e-9", "2.07e5", "0.3", ""] )\n');
    fprintf(fileID,'elementprops_create( "Indenter", 71, 25, 20, 11027, 1, 20, [13, 20, 1011,  @\n');
    fprintf(fileID,'11182], [5, 2, 1, 1], ["m:Rigid_steel", "", "", ""], )\n');
    % Printing commands for property generation
    fprintf(fileID,'elementprops_create( "%s",@\n',char('Indenter'));
    fprintf(fileID,'51, 25, 35, 11004, 1, 20,@\n');
    fprintf(fileID,'[13, 20, 36, 1004, 11044, 11136, 11027, 1011, 11182],@\n');
    fprintf(fileID,'[5, 2, 1, 1, 4, 3, 4, 1, 1],@\n');
    fprintf(fileID,'["m:%s", "", "%d", "0.833", "", "5", "", "", ""],@\n',char('Rigid_steel'),2);
    fprintf(fileID,'"" )\n');
    
    % Printing commands for mesh generation
    fprintf(fileID,'INTEGER fem_create_mesh_surfa_num_nodes\n');
    fprintf(fileID,'INTEGER fem_create_mesh_surfa_num_elems\n');
    fprintf(fileID,'STRING fem_create_mesh_s_nodes_created[VIRTUAL]\n');
    fprintf(fileID,'STRING fem_create_mesh_s_elems_created[VIRTUAL]\n');
    fprintf(fileID,'fem_create_mesh_surf_4( "Hybrid", 49664,@\n');
    fprintf(fileID,'"Surface %d:%d", 4, ["%d", "0.1", "0.2", "1.0"],@\n',sc,sc+1,esize);
    fprintf(fileID,'"Quad4", "#", "#", "Coord 0", "Coord 0",@\n');
    fprintf(fileID,'fem_create_mesh_surfa_num_nodes,@\n');
    fprintf(fileID,'fem_create_mesh_surfa_num_elems,@\n');
    fprintf(fileID,'fem_create_mesh_s_nodes_created,@\n');
    fprintf(fileID,'fem_create_mesh_s_elems_created )\n');
    fprintf(fileID,'fem_associate_elems_to_ep( "%s",@\n',char('Indenter'));
    fprintf(fileID,'fem_create_mesh_s_elems_created,@\n');
    fprintf(fileID,'fem_create_mesh_surfa_num_elems )\n');
    
else
    % Printing error message to screen
    fprintf('faulty input, radius bigger than length, no bulb has been made\n')
end

end