function [sc,fem_dat_sh,fem_dat_be,bc] = deck(fileID,xof,g_wss,g_lbwf,....
    ss_H,ds_ns,ds_W,sc,section,ds_plt_ds,ds_plt_lg,ds_plt_tg,ds_sti_ds,...
    ds_sti_lg,ds_sti_tg,fem_dat_sh,fem_dat_be,bc,hg,hknl)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Function for generation of PATRAN session file commands which will      %
% generate a deck section when run.                                       %
%                                                                         %
% Written by Halvor L. Aga as part of the work concerning                 %
% "Assessement if structural requirements related to LNG fuel tanks."     %
% Deadline 10. June 2013                                                  %
% Has been made by modification of recorded .ses commands in PATRAN.      %
%                                                                         %
% Input:                                                                  %
% fileID - file identification number of the file for writing             %
% xof - Offset in x direction for the section					          %
% g_wss - Width of the side section						                  %
% g_lbwf - Length between the web frames					              %
% ss_H - Vertical distance between the stringers				          %
% ds_ns - number of stiffeners in each distance between the longitudinal  %
%         girders                                                         %
% ds_W - Width between each of the longitudinal girders				      %
% sc - Counter for number of created surfaces					          %
% section - Information of placement of the section			              %
% ds_plt_ds - property numbers for plating in deck surface 			      %
% ds_plt_lg - property numbers for plating in longitudinal girders		  %
% ds_plt_tg - property numbers for plating in transversal girders		  %
% fem_dat_sh - matrix containing data regarding shell elements			  %
% fem_dat_be - matrix containing data regarding beam elements			  %
% bc - matrix containing data regarding boundary conditions			      %
%										                                  %
% Output:									                              %
% sc - Counter for number of created surfaces					          %
% fem_dat_sh - matrix containing data regarding shell elements			  %
% fem_dat_be - matrix containing data regarding beam elements			  %
% bc - matrix containing data regarding boundary conditions			      %
%										                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Determination of femc_sh, finite elements counter for shell elements
if (size(fem_dat_sh,2)==1); femc_sh = 0;
else femc_sh = size(fem_dat_sh,1);
end
% Determination of femc_be, finite elements counter for beam elements
if (size(fem_dat_be,2)==1); femc_be = 0;
else femc_be = size(fem_dat_be,1);
end
% Determination of bcc, counter for boundary conditions
if (size(bc,2)==1); bcc = 0;
else bcc = size(bc,1);
end

xofm = [xof, xof+(g_lbwf-800)/2, xof+(g_lbwf+800)/2];
lbwfm = [(g_lbwf-800)/2, 800, (g_lbwf-800)/2];

for b = 1:3
    i_xof = xofm(b);
    i_l = lbwfm(b);

%--------------------------------------------------------------------------
% Point generation

fprintf(fileID,'STRING asm_create_grid_xyz_created_ids[VIRTUAL]\n');

% Points on deck surface
y = g_wss; 			% Horizontal position of the point.
g_Hmd = sum(ss_H); 		% Height of the main deck in absolute coordinates
pc = 1; 				% point counter
fprintf(fileID,'asm_const_grid_xyz( "%d", "[%d %d %d]", "Coord 0",  @\n'...
    ,pc,i_xof,y,g_Hmd);
fprintf(fileID,'asm_create_grid_xyz_created_ids )\n');

sco = sc; % Storing number of existing surfaces

for j = 1:length(ds_ns)
    for i = 1:ds_ns(j)+1
        pc = pc + 1;
        y = y + ds_W(j)/(ds_ns(j)+1);
        fprintf(fileID,...
            'asm_const_grid_xyz( "%d", "[%d %d %d]", "Coord 0",  @\n'...
            ,pc,i_xof,y,g_Hmd);
        fprintf(fileID,'asm_create_grid_xyz_created_ids )\n');
    end
end

% Points for knuckle
pc =pc+1;
fprintf(fileID,'asm_const_grid_xyz( "%d", "[%d %d %d]", "Coord 0",  @\n'...
    ,pc,i_xof,g_wss,g_Hmd-hg-hknl);
fprintf(fileID,'asm_create_grid_xyz_created_ids )\n');
pc =pc+1;
fprintf(fileID,'asm_const_grid_xyz( "%d", "[%d %d %d]", "Coord 0",  @\n'...
    ,pc,i_xof,g_wss,g_Hmd-hg);
fprintf(fileID,'asm_create_grid_xyz_created_ids )\n');
pc =pc+1;
fprintf(fileID,'asm_const_grid_xyz( "%d", "[%d %d %d]", "Coord 0",  @\n'...
    ,pc,i_xof,g_wss+hknl,g_Hmd-hg);
fprintf(fileID,'asm_create_grid_xyz_created_ids )\n');

% Point generation finished
%--------------------------------------------------------------------------
% Curve generation

% Curves on deck surface
cc = 0; % Curve counter
fprintf(fileID,'STRING asm_line_2point_created_ids[VIRTUAL]\n');
for i = 1:sum(ds_ns)+length(ds_ns)
    cc = cc + 1;
    fprintf(fileID,'asm_const_line_2point( "%d", "point %d", @\n',i,i);
    fprintf(fileID,'"point %d", 0, "", 50., 1,  @\n',i+1);
    fprintf(fileID,'asm_line_2point_created_ids )\n');
end

% Curve generation finished
%--------------------------------------------------------------------------
% Surface generation

% Web of transverse girder

fprintf(fileID,'STRING sgm_sweep_surface_e_created_ids[VIRTUAL]\n');
for i = 1:sum(ds_ns)+length(ds_ns)
    sc = sc+1;
    fprintf(fileID,'sgm_const_surface_extrude( @\n');
    fprintf(fileID,...
        '"%d", "<0 0 %d>", 1., 0., "[0 0 0]", "Coord 0", @\n',sc,-hg);
    fprintf(fileID,' "Curve %d", sgm_sweep_surface_e_created_ids )\n',i);
    if section ~= 1 && b == 1
        % Store finite elements data for surface
        femc_sh =femc_sh + 1;
        fem_dat_sh(femc_sh,1) = sc; 			% Surface number
        fem_dat_sh(femc_sh,2) = ds_plt_tg(1); 	% Property number
        fem_dat_sh(femc_sh,3) = 1; 			% Mesh fineness
        % Store finite elements data for curve
        femc_be = femc_be +1;
        fem_dat_be(femc_be,1) = sc; 			% Surface number
        fem_dat_be(femc_be,2) = 2;  			% Curve side number
        fem_dat_be(femc_be,3) = ds_sti_tg(1);  	% Property number
        fem_dat_be(femc_be,4) = 1; 			% Mesh fineness
    end
end


% Knuckle surface
sc = sc+1;
fprintf(fileID,'STRING sgm_create_surface__created_ids[VIRTUAL]\n');
fprintf(fileID,'sgm_const_surface_vertex( @\n');
fprintf(fileID,'"%d", "Point %d", "Point %d", "Point %d", "Point %d", @\n'...
    ,sc,pc-2,pc-1,pc,pc);
fprintf(fileID,'sgm_create_surface__created_ids )\n');
if section ~= 1 && b == 1
    femc_sh = femc_sh + 1;
    fem_dat_sh(femc_sh,:) = [sc ds_plt_tg(2) 1];
    femc_be = femc_be +1;
    fem_dat_be(femc_be,:) = [sc 4 ds_sti_tg(2) 1];
end

% Extrude longitudinal surfaces to one section
fprintf(fileID,'STRING sgm_sweep_surface_e_created_ids[VIRTUAL]\n');
count = 0;
for i = 1:length(ds_ns)
    for j = 1:ds_ns(i)+1
        count = count + 1;
        sc = sc + 1;
        fprintf(fileID,'sgm_const_surface_extrude( @\n');
        fprintf(fileID,...
            '"%d", "<%d 0 0>", 1., 0., "[0 0 0]", "Coord 0", @\n',sc,i_l);
        fprintf(fileID,...
            ' "Curve %d", sgm_sweep_surface_e_created_ids )\n',count);
        femc_sh =femc_sh + 1;
        fem_dat_sh(femc_sh,1) = sc;
        fem_dat_sh(femc_sh,2) = ds_plt_ds(i);
        fem_dat_sh(femc_sh,3) = 1;
        % Create boundary conditions only if section is an end section or
        % the curve lies along the midline of the ship
        if section == 1 && b == 1
            bcc = bcc + 1;
            bc(bcc,1) = sc; % Surface number
            bc(bcc,2) = 4;  % Curve side number
            bc(bcc,3) = 1;  % Boundary conditions type
        elseif section == 3 && b == 3
            bcc = bcc + 1;
            bc(bcc,1) = sc;
            bc(bcc,2) = 2;
            bc(bcc,3) = 1;
        end
        % Create webframes if the section is not the first section
        if j~=1
            femc_be = femc_be +1;
            fem_dat_be(femc_be,1) = sc;
            fem_dat_be(femc_be,2) = 1;
            fem_dat_be(femc_be,3) = ds_sti_ds(i);
            fem_dat_be(femc_be,4) = 1;
        end
    end
end

% Longitudinal girders
for i = 1 : length(ds_ns)
    sc = sc + 1;
    fprintf(fileID,'sgm_const_surface_extrude( @\n');
    fprintf(fileID,'"%d", "<%d 0 0>", 1., 0., "[0 0 0]", "Coord 0", @\n'...
        ,sc,i_l);
    fprintf(fileID,...
        ' "Surface %d.3", sgm_sweep_surface_e_created_ids )\n'...
        ,sum(ds_ns(1:i))+i+sco);
    femc_sh =femc_sh + 1;
    fem_dat_sh(femc_sh,:) = [sc ds_plt_lg(i) 1];
    femc_be = femc_be +1;
    fem_dat_be(femc_be,:) = [sc,3,ds_sti_lg(i) 1];
     if section == 1 && b == 1
            bcc = bcc + 1;
            bc(bcc,1) = sc; % Surface number
            bc(bcc,2) = 4;  % Curve side number
            bc(bcc,3) = 1;  % Boundary conditions type
        elseif section == 3 && b == 3
            bcc = bcc + 1;
            bc(bcc,1) = sc;
            bc(bcc,2) = 2;
            bc(bcc,3) = 1;
        end
end

% Surface generation finished
%--------------------------------------------------------------------------
% Cleaning

% Delete points and curves used
fprintf(fileID,'STRING asm_delete_point_deleted_ids[VIRTUAL]\n');
fprintf(fileID,...
    'asm_delete_point( "Point 1:3000", asm_delete_point_deleted_ids )\n');
fprintf(fileID,'STRING asm_delete_curve_deleted_ids[VIRTUAL]\n');
fprintf(fileID,...
    'asm_delete_curve( "Curve 1:100", asm_delete_curve_deleted_ids )\n');

% Cleaning finished
%--------------------------------------------------------------------------
end
end