function [] = keyman(filename,addfilename,finishfilename,ofm,bn)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function adds the keyword entries given in a file called           %
% the variable stored in addfilename to a file with name finishfilename   %
% and reads nodes, elements, bc's, sections and parts from the file with  %
% filename stored as variable in filename.                                %
%                                                                         %
% Written by Halvor L. Aga as part of the work concerning                 %
% "Assessement if structural requirements related to LNG fuel tanks."     %
% Deadline 10. June 2013                                                  %
% Has been made by modification of recorded .ses commands in PATRAN.      %
%                                                                         %
% Input:                                                                  %
% filename       - Path and name of the .ses file containing model data   %
%                  from PATRAN          						          %
% addfilename    - Path and name of the file containing keyword commands  %
%                  necessary for the analysis                             %
% finishfilename - Desired name of the finished file                      %
% ofm            - Matrix containing data about offsets                   %
% bn             - Corresponding names to the offset matrix		          %
%										                                  %
% Output:									                              %
% None										                              %
%				 						                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Open files
keywordID = fopen(filename,'r');
addkeyID = fopen(addfilename,'r');
finishID = fopen(finishfilename,'w');

% Create keyword entries from addfilename file
for i = 1:2 % Omitting lines
    fgetl(addkeyID);
end

n = strread(fgets(addkeyID));
for i = 1:n
    line = fgets(addkeyID);
    fprintf(finishID,line);
end


% Close file with lines added
fclose(addkeyID);

% Adding model data from the file named filename
% Omitting lines in file until *NODE is reached
S = 0;
while strcmp(strcat(line),'*NODE') == 0
    line = fgets(keywordID);
end

S = 0;
% Printing file lines until $ is reached
while strcmp(strcat(line),'$') == 0
    % Special treatment of sections starting with *PART
    if strcmp(strcat(line),'*PART') == 1;
        fprintf(finishID,line);
        line = fgets(keywordID);
        part = line;
        fprintf(finishID,part);
        line = fgets(keywordID);
        fprintf(finishID,line);
        line = fgets(keywordID);
        fprintf(finishID,line);
        % Changing element type from beam to beam
        % with offset and orientation
        if strcmp(strcat(line),'*SECTION_BEAM');
            line = fgets(keywordID);
            fprintf(finishID,line);
            line = fgets(keywordID);
            [d1 d2 d3 d4 d5 d6] = strread(line);
            fprintf(finishID,...
                '\t\t %.2f %9.2f %9.2f %9.2f %8.2f %9.2f\n'...
                ,d1,d2,d3,d4,d5,-d6);
            storeline = line;
            line = fgets(keywordID);
            fprintf(finishID,'*ELEMENT_BEAM_ORIENTATION_OFFSET');
            fprintf(finishID,'\n');
            for i = 1:length(bn)
                if strcmp(strcat(part),bn(i))== 1
                    c = i;
                end
            end
            line = fgets(keywordID);
            while strcmp(strcat(line),'*PART') == 0 &&...
                    strcmp(strcat(line),'$') == 0
                line2 = fgets(keywordID);
                [b1 b2 b3 b4 b5] = strread(line);
                [c1 c2 c3] = strread(line2);
                [a1 a2 a3 a4 a5 a6] = strread(storeline);
                fprintf(finishID,line);
                fprintf(finishID,line2);
                fprintf(finishID,...
                    '\t\t %.2f %9.2f %9.2f %9.2f %9.2f %9.2f %9.2f',...
                    ofm(c,1),ofm(c,2),ofm(c,3),ofm(c,1),ofm(c,2),ofm(c,3));
                fprintf(finishID,'\n');
                line = fgets(keywordID);
            end
        end
    end
    if strcmp(strcat(line),'*PART') == 0
        fprintf(finishID,line);
        line = fgets(keywordID);
    end
end

% Read and omit lines until boundary conditions is reached
line = fgets(keywordID);
while length(line) <= 10||strcmp(strcat(line(1:11)),'$ LBC set :') == 0
    line = fgets(keywordID);
end    

% Copy and change the boundary conditions
while(strcmp(strcat(line),'*SET_NODE_LIST_GENERATE') == 0)
    ax = line(13);
    fgets(keywordID); % omitting line
    line = fgets(keywordID);
    fprintf(finishID,line);
    line = fgets(keywordID); % omitting line
    nmbr  = line(1:10);
    bc1 = '         0         1         1         1         1         1         1\n';
    bc2 = '         0         1         1         1         1         1         1\n';
    % Implement the right boundary conditions
    if strcmp(strcat(ax),'1') == 1
        line = strcat(nmbr,bc1);
    elseif strcmp(strcat(ax),'2') == 1
        line = strcat(nmbr,bc2);
    end
    % Copy lines until $ is reached
    while (strcmp(strcat(line(1)),'$') == 0)
        fprintf(finishID,line);
        line = fgets(keywordID);
    end
    line = fgets(keywordID);
end
% Printing end sign to file
fprintf(finishID,'*END');

% Closing files used
fclose(keywordID);
fclose(finishID);

end