function [offsetm,bpname,WF,STR] = model_generation(filesID,filepath1,...
    filepath2)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function generates the models needed to create a full ship section %
% for analysis in LS-DYNA by the use of a PATRAN session file.            %
%                                                                         %
% Written by Halvor L. Aga as part of the work concerning                 %
% "Assessement if structural requirements related to LNG fuel tanks."     %
% Deadline 10. June 2013                                                  %
% Has been made by modification of recorded .ses commands in PATRAN.      %
%                                                                         %
% Build-up:                                                               %
%      1. Read input data from file                                       %
%      2. Write necessary commands to a .ses file for creation of:        %
%        1. Ship section geometry                                         %
%        3. Meshing                                                       %
%        2. Bulbs                                                         %
%        4. Analysis commands (commands to make PATRAN make  .key         %
%           files for each of the bow positions compatible with LS-DYNA)  %
%                                                                         %
% Input:                                                                  %
%      filesID: Vector with file identifiers for files used               %
%      filepath1: File path to location of files written including .ses   %
%                 filename                                                %
%      filepath2: File path to location of files written                  %
%      filename: The name of the executable .ses file                     %
%                                                                         %
% Output:                                                                 %
%      offsetm: Matrix containing data for creating beam offset           %
%      bpname: Vector including ordered names for creating beam offset    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%
% Read input data from file:

% Open input file:
inputID = filesID(2);
for i = 1:4 % Omitting lines
    fgets(inputID);
end

% Read filename (not used)
fgetl(inputID);

% Read input data:
for i =1:3 % Omitting lines
    fgets(inputID);
end

% Sections to be made
section = strread(fgets(inputID));

for i =1:3 % Omit lines
    fgets(inputID);
end
WF = length(section)-1;

% General data:
[g_wss g_lbwf g_Htt] = strread(fgets(inputID));

for i =1:3 % Omit lines
    fgets(inputID);
end

% Bow data
[R1 R2 L] = strread(fgets(inputID));

for i =1:3 % Omit lines
    fgets(inputID);
end

% Deck structure data:
% Width of each section                   [mm]
ds_W  = strread(fgets(inputID));
fgets(inputID);
% Number of stiffeners in each section    [-]
ds_ns = strread(fgets(inputID));
fgets(inputID);
% Property numbers for shell in deck surface
ds_plt_ds = strread(fgets(inputID));
fgets(inputID);
% Property numbers for shell in longitudinal girders
ds_plt_lg = strread(fgets(inputID));
fgets(inputID);
% Property numbers for shell in transverse girder and knuckle
ds_plt_tg = strread(fgets(inputID));
fgets(inputID);
% Property numbers for stiffeners in deck surface
ds_sti_ds = strread(fgets(inputID));
fgets(inputID);
% Property numbers for stiffeners on longitudinal girders
ds_sti_lg = strread(fgets(inputID));
fgets(inputID);
% Property numbers for stiffeners on transverse girder and knuckle
ds_sti_tg = strread(fgets(inputID));

for i =1:3 % Omitting lines
    fgets(inputID);
end

% Side section data:
% Height of each segment                    [mm]
ss_H     = strread(fgets(inputID));
fgets(inputID);
% Number of stiffeners per stringer distance[-]
ss_nst   = strread(fgets(inputID));
fgets(inputID);

STR = length(ss_nst)-1;
% Property numbers for shell in outer skin
ss_plt_os  = strread(fgets(inputID));
fgets(inputID);
% Property numbers for shell in inner skin
ss_plt_is  = strread(fgets(inputID));
fgets(inputID);
% Property numbers for shell in web frame
ss_plt_wf(1,:)  = strread(fgets(inputID));
fgets(inputID);
% Property numbers for shell with manholes in web frame
ss_plt_wf(2,:)  = strread(fgets(inputID));
fgets(inputID);
% Property numbers for shell in tank top, stringers and deck
ss_plt_str(1,:) = strread(fgets(inputID));
fgets(inputID);
% Property numbers for shell with manholes in tank top, stringers and deck
ss_plt_str(2,:) = strread(fgets(inputID));
fgets(inputID);
% Property numbers for stiffeners in web frame
ss_sti_wf  = strread(fgets(inputID));
fgets(inputID);
% Property numbers for stiffeners in tank top, stringers and deck
ss_sti_str = strread(fgets(inputID));
fgets(inputID);
% Property numbers for stiffeners in outer skin
ss_sti_os  = strread(fgets(inputID));
fgets(inputID);
% Property numbers for stiffeners in inner skin
ss_sti_is  = strread(fgets(inputID));

for i =1:2 % Omit lines
    fgets(inputID);
end

% Data for manholes
wmh =strread(fgets(inputID)); % Width

for i =1:3 % Omit lines
    fgets(inputID);
end

% Double bottom data:
% Width in each section                      [mm]
db_W = strread(fgets(inputID));
fgets(inputID);
% Number of stiffeners in section 1, 2 and 3 [-]
db_ns = strread(fgets(inputID));
fgets(inputID);
% Property numbers for shell in outer skin
db_plt_os  =strread(fgets(inputID));
fgets(inputID);
% Property numbers for shell at tanktop
db_plt_tt  =strread(fgets(inputID));
fgets(inputID);
% Property numbers for shell in web frame
db_plt_wf(1,:)  = strread(fgets(inputID));
fgets(inputID);
% Properties for shell with manhole cutout and drillings
db_plt_wf_s =strread(fgets(inputID));
fgets(inputID);
% Property numbers for stiffeners in web frame
db_sti_wf  = strread(fgets(inputID));
fgets(inputID);
% Property numbers for shell in longitudinal girders
db_plt_str(1,:) = strread(fgets(inputID));
fgets(inputID);
% Property numbers for reduced shell in longitudinal girders
db_plt_str(2,:) = strread(fgets(inputID));
fgets(inputID);
% Property numbers for stiffeners in longitudinal girders
db_sti_str = strread(fgets(inputID));
fgets(inputID);
% Property numbers for stiffeners in outer skin
db_sti_os  = strread(fgets(inputID));
fgets(inputID);
% Property numbers for stiffeners in tanktop
db_sti_tt  = strread(fgets(inputID));
%%

hg = 550;   % Height of transverse girder
hknl = 600; % Height dimension of knuckle
% Create counters used in the whole program
sc = 0; % Surface counter

% Create matrices for storage of meshing data
fem_dat_sh = 0; % Shell element data
fem_dat_be = 0; % Beam element data
bc=0; % Boundary condition data

% Session file generation:
% Create file and setting viewport
initialize(filesID(1),filepath1,filepath2);
% Creating ship section
for i = 1:length(section)
    
    % Offset in x-direction
    xof = g_lbwf*(i-length(section)/2-1);
    
    % Write commands for deck structure to .ses file
    [sc,fem_dat_sh,fem_dat_be,bc] = deck(filesID(1),xof,g_wss,g_lbwf,....
    ss_H,ds_ns,ds_W,sc,section(i),ds_plt_ds,ds_plt_lg,ds_plt_tg,ds_sti_ds,...
    ds_sti_lg,ds_sti_tg,fem_dat_sh,fem_dat_be,bc,hg,hknl);
    
    % Write commands for side section to .ses file
    [sc,fem_dat_sh,fem_dat_be,bc] = side_section(filesID(1),xof,g_wss,...
        g_lbwf,ss_H,ss_nst,sc,ss_plt_os,ss_plt_is,ss_plt_wf,ss_sti_wf,...
        ss_plt_str,ss_sti_str,ss_sti_os,ss_sti_is,fem_dat_sh,fem_dat_be,...
        section(i),bc);
    
    % Write commands for double bottom to .ses file
    [sc,fem_dat_sh,fem_dat_be,bc] = double_bottom(filesID(1),xof,g_lbwf,...
        g_Htt,db_ns,db_W,g_wss,sc,wmh,section(i),db_plt_os,db_plt_tt,...
        db_plt_wf,db_sti_wf,db_plt_str,db_sti_str,db_sti_os,db_sti_tt,...
        fem_dat_sh,fem_dat_be,db_plt_wf_s,bc);
end

% Create meshing
[offsetm,bpname,finemesh]=mesh(filesID(1),fem_dat_sh,fem_dat_be,bc,filesID);
% Calculate bow positions
bpos = [0 -101  ss_H(1)/2;
    0 -101  ss_H(1);
    g_lbwf/2 -101  ss_H(1);
    g_lbwf/2 -101  ss_H(1)+ss_H(2)/2];
% Save without bulb
nobulb = [filepath2 '\nobulb.db'];
fprintf(filesID(1),'uil_file_saveas.copy( "%s", FALSE )\n',nobulb);
fprintf(filesID(1),'uil_file_close.go(  )\n');
% Create keyword file for each bow position
for i = 1:4
    % Open shipside model
    fprintf(filesID(1),'uil_file_open.go( "%s" )\n',nobulb);
    % Save with new filename
    abulb = [filepath2 '\bulb' num2str(i) '.db'];
    fprintf(filesID(1),'uil_file_saveas.copy( "%s", FALSE )\n',abulb);
    % Open new file
    fprintf(filesID(1),'uil_file_close.go(  )\n');
    fprintf(filesID(1),'uil_file_open.go( "%s" )\n',abulb);
    % Create bulb
    bulb(filesID(1),R1,R2,L,bpos(i,3),bpos(i,2),bpos(i,1),sc,2*finemesh);
    % Create keyword file
    analysis(filesID(1),['bulb' num2str(i)],filepath2);
end

end