function [] = postscript(WF,STR,loc,fileID,studyname)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function generates the neccessary session file commands to create  %
% a postscript file for generating a energy indentation curve from four   %
% different bow position simulations                                      %
%                                                                         %
% Written by Halvor L. Aga as part of the work concerning                 %
% "Assessement if structural requirements related to LNG fuel tanks."     %
% Deadline 10. June 2013                                                  %
% Has been made by modification of recorded .ses commands in PATRAN.      %
%                                                                         %
%                                                                         %
% Input:                                                                  %
%       WF - number of webframes in a tank hold                           %
%       STR - number of stringers in sidesection                          %
%       loc - filepath to folder where the results are stored             %
%       fileID - identification key to the postprocessing file            %
%       studyname - name of the study                                     %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

U = (2*STR+1)*(2*WF+1);
W = [STR*WF/U (STR+1)*WF/U (STR+1)*(WF+1)/U STR*(WF+1)/U];

% Preparing the intividual curves
for i = 1:4
fprintf(fileID,'ascii rcforc open "%s\\bow_pos_#%d\\rcforc" 0\n',loc,i);
fprintf(fileID,'ascii rbdout open "%s\\bow_pos_#%d\\rbdout" 0\n',loc,i);
fprintf(fileID,'ascii rcforc plot 2 Sl-2\n');
fprintf(fileID,'xyplot 1 operation inverty all\n');
fprintf(fileID,...
    'xyplot 1 savefile curve_file "%s\\bow_pos_#%d\\Force%d" 1 all\n',loc,i,i);
fprintf(fileID,'ascii rbdout plot 5 1\n');
fprintf(fileID,...
    'xyplot 1 savefile curve_file "%s\\bow_pos_#%d\\Displacement%d" 1 all\n'...
    ,loc,i,i);
fprintf(fileID,'cross Force%d~1 Displacement%d~1 1000\n',i,i);
fprintf(fileID,...
    'xyplot 1 savefile curve_file "%s\\bow_pos_#%d\\ForceDisplacement%d" 1 all\n'...
    ,loc,i,i);
fprintf(fileID,'print jpg "%s\\bow_pos_#%d\\FoDisp%d.jpg" LANDSCAPE nocompress gamma 1.000 transparent 0x000000 enlisted "PlotWindow-1" \n',loc,i,i); 
fprintf(fileID,'xyplot 1 operation integrate all\n');
fprintf(fileID,'xyplot 1 curvelegend 1//1 %s_bowpos#%d\n',studyname,i);
fprintf(fileID,'xyplot 1 legend on\n');
fprintf(fileID,'xyplot 1 legendlabel ""\n');
fprintf(fileID,...
    'xyplot 1 savefile curve_file "%s\\bow_pos_#%d\\EnergyDisplacement%d" 1 all\n'...
    ,loc,i,i);
fprintf(fileID,'print jpg "%s\\bow_pos_#%d\\EnDisp%d.jpg" LANDSCAPE nocompress gamma 1.000 transparent 0x000000 enlisted "PlotWindow-1" \n',loc,i,i); 
fprintf(fileID,'removefile "%s\\bow_pos_#%d\\Force%d"\n',loc,i,i);
fprintf(fileID,'removefile "%s\\bow_pos_#%d\\Displacement%d"\n',loc,i,i);
fprintf(fileID,'removefile "%s\\bow_pos_#%d\\ForceDisplacement%d"\n',loc,i,i);
fprintf(fileID,'removefile "%s\\bow_pos_#%d\\EnergyDisplacement%d"\n',loc,i,i);
fprintf(fileID,'deletewin 1\n');
fprintf(fileID,'ascii rcforc uload\n');
fprintf(fileID,'ascii rbdout uload\n');
end

% Combining to form one energy curve
for i = 1:4
    if i >= 2
    fprintf(fileID,'addplot\n');
    end
    fprintf(fileID,'open xydata "%s\\bow_pos_#%d\\EnergyDisplacement%d"\n',loc,i,i);
    fprintf(fileID,'show "EnergyDisplacement%i" 0\n',i);
    fprintf(fileID,'removefile "%s\\bow_pos_#%d\\EnergyDisplacement%d"\n',loc,i,i);
end

% Scaling according to scale factors
for i = 1:4
fprintf(fileID,'xyplot 1 select clear\n');
fprintf(fileID,'xyplot 1 select %d\n',i);
fprintf(fileID,'xyplot 1 xoffset 0 yoffset 0 xscale 1.000000 yscale %f \n',W(i));
end

% Summing the curves

fprintf(fileID,'xyplot 1 operation sum_curves all\n');

% Changing axe titles and gridlines
fprintf(fileID,'xyplot 1 xmin -100 \n');
fprintf(fileID,'xyplot 1 xmax 3680\n');
fprintf(fileID,'xyplot 1 xoffset -100\n');
fprintf(fileID,'xyplot 1 xtitle "Indentation [mm]"\n');
fprintf(fileID,'xyplot 1 ytitle "Energy [J]"\n');
fprintf(fileID,'xyplot 1 curvelegend 1/1 "EnergyIndentation_%s\n"',studyname);
fprintf(fileID,'xyplot 1 legendlabel ""\n');
fprintf(fileID,'xyplot 1 legend off\n');
fprintf(fileID,'xyplot 1 minorgrid on\n');
fprintf(fileID,'xyplot 1 title "EnergyIndentation_%s"\n',studyname);
% Saving finished plot
fprintf(fileID,'xyplot 1 savefile curve_file "%s\\Energyplot_%s" 1 all\n',loc,studyname);
% Printing finished plot to .jpg format
fprintf(fileID,'xyplot 1 select 1\n');
fprintf(fileID,'xyplot 1 show select\n');
fprintf(fileID,'xyplot 1 xmin -100 \n');
fprintf(fileID,'xyplot 1 xmax 3680\n');
fprintf(fileID,'xyplot 1 xoffset -100\n');
fprintf(fileID,'print jpg "%s\\%s.jpg" LANDSCAPE nocompress gamma 1.000 transparent 0x000000 enlisted "PlotWindow-1" \n',loc,studyname); 
fprintf(fileID,'removefile "%s\\Energyplot_%s" 1 all\n',loc,studyname);
fclose(fileID);

end