function [sn] = prep_string(fileID,coord,breaks,ax,sn)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function generates the neccessary session file commands to break   %
% a number of surfaces and contsruct a new surface between them.          %
%                                                                         %
% Written by Halvor L. Aga as part of the work concerning                 %
% "Assessement if structural requirements related to LNG fuel tanks."     %
% Deadline 10. June 2013                                                  %
% Has been made by modification of recorded .ses commands in PATRAN.      %
%                                                                         %
% Build-up:                                                               %
% 1. Creation of points and lines for breaking                            %
% 2. Breaking of surfaces                                                 %
% 3. Deletion of initial surfaces, break curves and points                %
% 4. Create new surface                                                   %
%                                                                         %
% Input:                                                                  %
%       fileID: The file ID of the file for storage of commands, file must%
%               be open.                                                  %
%       coord: Set of coordinates for break curves.                       %
%       breaks: Vector containing surfaces to break.                      %
%       ax: Variable for changing direction of break.                     %
%       sn: Surface counter containing all previously made surfaces       %
%                                                                         %
% Output:                                                                 %
%        sn: Surfece counter containing new surfaces                      %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Generate points for stringers and manhole generation
fprintf(fileID,'asm_const_grid_xyz( "%d", "[%d %d %d]", "Coord 0",  @\n'...
    ,2001,coord(1,1),coord(1,2),coord(1,3));
fprintf(fileID,'asm_create_grid_xyz_created_ids )\n');
fprintf(fileID,'asm_const_grid_xyz( "%d", "[%d %d %d]", "Coord 0",  @\n'...
    ,2002,coord(2,1),coord(2,2),coord(2,3));
fprintf(fileID,'asm_create_grid_xyz_created_ids )\n');
fprintf(fileID,'asm_const_grid_xyz( "%d", "[%d %d %d]", "Coord 0",  @\n'...
    ,2003,coord(3,1),coord(3,2),coord(3,3));
fprintf(fileID,'asm_create_grid_xyz_created_ids )\n');
fprintf(fileID,'asm_const_grid_xyz( "%d", "[%d %d %d]", "Coord 0",  @\n'...
    ,2004,coord(4,1),coord(4,2),coord(4,3));
fprintf(fileID,'asm_create_grid_xyz_created_ids )\n');

% Generate curves for breaking of surfaces
fprintf(fileID,'STRING asm_line_2point_created_ids[VIRTUAL]\n');
fprintf(fileID,'asm_const_line_2point( "2001", "point 2001", @\n');  
fprintf(fileID,...
    '"point 2003", 0, "", 50., 1, asm_line_2point_created_ids )\n');
fprintf(fileID,'asm_const_line_2point( "2002", "point 2002", @\n');
fprintf(fileID,...
    '"point 2004", 0, "", 50., 1,asm_line_2point_created_ids )\n');

% Breake surfaces
if ax == 1;
    c1 = 2001;
    c2 = 2002;
elseif ax == 2;
    c1 = 2002;
    c2 = 2001;
end

for j = 1:length(breaks)
    i=breaks(j);
    sn = sn+1;
    fprintf(fileID,'STRING sgm_surface_break_c_created_ids[VIRTUAL]\n');
    fprintf(fileID,'sgm_edit_surface_break_v1( "%d",@\n',sn);
    fprintf(fileID,'"Surface %d", FALSE, 3, 0, 0., "", "",@\n',i);
    fprintf(fileID,'"Curve %d", sgm_surface_break_c_created_ids )\n',c1);   
    fprintf(fileID,'STRING asm_delete_any_deleted_ids[VIRTUAL]\n');
    fprintf(fileID,'asm_delete_surface( "Surface %d", @\n',i);
    fprintf(fileID,'asm_delete_any_deleted_ids )\n');
    fprintf(fileID,'STRING sgm_surface_break_c_created_ids[VIRTUAL]\n');
    fprintf(fileID,'sgm_edit_surface_break_v1( "%d",@\n',sn+2);
    fprintf(fileID,'"Surface %d", FALSE, 3, 0, 0., "",@\n',sn+1);
    fprintf(fileID,...
        '"", "Curve %d", sgm_surface_break_c_created_ids )\n',c2);
    fprintf(fileID,'STRING asm_delete_any_deleted_ids[VIRTUAL]\n');
    fprintf(fileID,'asm_delete_surface( "Surface %d",@\n',sn+1);
    fprintf(fileID,'asm_delete_any_deleted_ids )\n');
    fprintf(fileID,'asm_delete_surface( "Surface %d",@\n',sn+2);
    fprintf(fileID,'asm_delete_any_deleted_ids )\n');
    fprintf(fileID,'STRING sgm_renum_surface_new_ids[VIRTUAL]\n');
    fprintf(fileID,'sgm_renumber( 1, "surface",@\n');
    fprintf(fileID,...
        '"%d", "Surface %d", sgm_renum_surface_new_ids )\n',i,sn+3);
end

% Deletion of break curves
fprintf(fileID,'STRING asm_delete_curve_deleted_ids[VIRTUAL]\n');
fprintf(fileID,...
    'asm_delete_curve( "Curve 2001", asm_delete_curve_deleted_ids )\n');
fprintf(fileID,...
    'asm_delete_curve( "Curve 2002", asm_delete_curve_deleted_ids )\n');

% New surface
fprintf(fileID,'STRING sgm_create_surface__created_ids[VIRTUAL]\n');
fprintf(fileID,'sgm_const_surface_vertex( "%d", "Point 2001",@\n',sn+1);
fprintf(fileID,'"Point 2002", "Point 2004", "Point 2003", @\n');
fprintf(fileID,'sgm_create_surface__created_ids )\n');

% Delete all used points
fprintf(fileID,'STRING asm_delete_point_deleted_ids[VIRTUAL]\n');
fprintf(fileID,...
    'asm_delete_point( "Point 2001:%d", asm_delete_point_deleted_ids )\n'...
    ,2004+2*(length(breaks)-1));

% Updating the surface counter
sn = sn + 1;

end