%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Script for making a series of convergence analysis executable in LS-DYNA%
%                                                                         %
% Written by Halvor L. Aga as part of the work concerning                 %
% "Assessement if structural requirements related to LNG fuel tanks."     %
% Deadline 10. June 2013                                                  %
% Has been made by modification of recorded .ses commands in PATRAN.      %
%                                                                         %
% Build-up:                                                               %
%      0. Check if parts of the study exists.                             %
%        1. Stop if it does.                                              %
%      1. Create study map structure.                                     %
%      2. Copy input files                                                %
%      3. Open files                                                      %
%      4. Create the .ses by function model_generation                    %
%      5. Manual intervation: Excecute the .ses files in PATRAN           % 
%      6. Manipulate keyword files from PATRAN for boundary conditions,   %
%         beam offset and to implement necessary keyword commands as given%
%         in "keyword" file.                                              %
%      7. Write the location of the input file, as well as the location of%
%         the results file in a output file.                              %
%                                                                         %
% Input:                                                                  %
%      input.txt        - File containing input for the geometrical       %
%	   sectioninput.txt - File containing input for sections and mesh     %
%                         sizes                                           %
% 	   keyword.txt      - File containing all necessary keyword commands  %
%                         for execution in LS-DYNA                        %
% Output:                                                                 %
%      Keyword files with analysis ready for execution in LS-DYNA         % 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Clearing variables
clear all;
clc;

rootfolder = cd;
studyname  = 'Original';
inputfilefolder = [cd '\Input_files'];

if exist([rootfolder '\' studyname],'file') == 0
        dbloc=[rootfolder '\' studyname '\database'];
        mkdir(dbloc);
        copyfile([inputfilefolder '\' 'input.txt'],dbloc)
        copyfile([inputfilefolder '\' 'sectioninput.txt'],dbloc)
        copyfile([inputfilefolder '\' 'keyword.txt'],dbloc)
        
        
        %Create file for .ses file storage
        fileID(1) =  fopen([dbloc '\' 'modelfile.ses'],'w');
        % Open input files
        fileID(2) =  fopen([dbloc '\' 'input.txt'],'r');
        fileID(3) =  fopen([dbloc '\' 'sectioninput.txt'],'r');
        fileID(4) =  fopen([dbloc '\' 'keyword.txt'],'r+');        
        
        filepath = [dbloc '\' 'modelfile.ses'];
        % Generate session file
        [offset,bpname,WF,STR] = model_generation(fileID,filepath,dbloc);
        % Nesting of offset and byname
        offsetsaml(1,:) = offset(:,1);
        offsetsaml(2,:) = offset(:,2);
        offsetsaml(3,:) = offset(:,3);
        bpnamesaml(1,:) = bpname(:,1);
        for j = 1:4
            caseloc = [rootfolder '\' studyname '\' 'bow_pos_#' num2str(j)];
            mkdir(caseloc)
        end

    loc = [rootfolder '\' studyname];
    postID = fopen([rootfolder '\' studyname '\' 'postscript.ses'],'w');
    postscript(WF,STR,loc,postID,studyname);
   
    [dbloc '\' 'modelfile.ses']
    
    % Run session files manually in PATRAN
    reply = input('Press Y when session file listed over is been manually executed by PATRAN (0 to abort):\n','s');
    
    if reply == 'Y'
         % Create file for storage of work file locations
        workID = fopen([rootfolder '\' studyname '\' 'workfile'],'w');
            dbloc=[rootfolder '\' studyname '\database'];
            for j = 1:4
                caseloc = [rootfolder '\' studyname '\' 'bow_pos_#' num2str(j)];
                filename = [dbloc '\' 'bulb' num2str(j) '.key'];
                addfilename = [dbloc '\' 'keyword.txt'];
                finishfilename = [caseloc '\' 'finishedfile.key'];
                % Un-nesting of offset and bpname
                offset(:,1) = offsetsaml(1,:);
                offset(:,2) = offsetsaml(2,:);
                offset(:,3) = offsetsaml(3,:);
                bpname(:,1) = bpnamesaml(1,:);
                % Add keywords to keyword file from PATRAN
                keyman(filename,addfilename,finishfilename,offset,bpname);
                % Store location of the finished keyword file to work list
                workfile = [finishfilename];
                % Store location of work list
                fprintf(workID, '%s\n', workfile );
            end
        fprintf('workfilenames and output folders written to files in studymap\n')
    else
        fprintf('Excecution aborted\n')
    end
else
   fprintf('Folder exists, nothing has been done. Specify unique name and rerun\n')
end

fclose('all');


% End of script