function [sc,fem_dat_sh,fem_dat_be,bc] = side_section(fileID,xof,g_wss,...
    g_lbwf,ss_H,ss_nst,sc,ss_plt_os,ss_plt_is,ss_plt_wf,ss_sti_wf,...
    ss_plt_str,ss_sti_str,ss_sti_os,ss_sti_is,fem_dat_sh,fem_dat_be,...
    section,bc)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function generates the neccessary session file commands to create  %
% a sidesection of a hull between two web frames by the use of a PATRAN   %
% session file.                                                           %
%                                                                         %
% Written by Halvor L. Aga as part of the work concerning                 %
% "Assessement if structural requirements related to LNG tanks."          %
% Deadline on 10. June 2013                                               %
% Has been made by modification of recorded .ses commands in PATRAN.      %
%                                                                         %
% Build-up:                                                               %
% 1. Determintation of counters used for storage of finite elements and   %
%    boundary conditions data.                                            %
% 2. Determintation of offsets and lengths of section before manhole, with%
%    manhole and after manhole                                            %
% 3. Generation of geometry and storage of FEM data and BC data. (Done in %
%    loop to create separate platefields where manholes exist.)           %
%    1. Generation of curves for extrusion                                %
%    2. Extrusion of:                                                     %
%       1. Web frame                                                      %
%       2. Inner skin                                                     %
%       3. Outer skin                                                     %
%       4. Stringers                                                      %
%       5. Deck                                                           %
%    3. Deletion of temporary curves and points                           %
%                                                                         %
% For input and output descriptions see model_generation.m                %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Determinate femc_sh, finite elements counter for shell elements
if (size(fem_dat_sh,2)==1); femc_sh = 0;
else femc_sh = size(fem_dat_sh,1);
end
% Determinate femc_be, finite elements counter for beam elements
if (size(fem_dat_be,2)==1); femc_be = 0;
else femc_be = size(fem_dat_be,1);
end
% Determinate bcc, counter for boundary conditions
if (size(bc,2)==1); bcc = 0;
else bcc = size(bc,1);
end
% Calculate offset and length of each subsection
xofm = [xof, xof+(g_lbwf-800)/2, xof+(g_lbwf+800)/2];
lbwfm = [(g_lbwf-800)/2, 800, (g_lbwf-800)/2];

% Generate three sub sections
for b = 1:3
    % Chose lenght and offset of current subsection
    i_xof = xofm(b);
    i_l = lbwfm(b);
    lb = 0; % Switch for breaking of top plating of inner skin
    % Input generation for points
    fprintf(fileID,'STRING asm_create_grid_xyz_created_ids[VIRTUAL]\n');
    % Create bottom points
    z = 0;
    pc = 1; % Point counter
    fprintf(fileID,'asm_const_grid_xyz( "%d", "[%d %d %d]",  @\n',...
        pc,i_xof,0,z);
    fprintf(fileID,'"Coord 0", asm_create_grid_xyz_created_ids )\n');
    for i = 1:length(ss_H) % Number of plate fields in height direction
        for j = 1:ss_nst(i)+1 % Number of stiffener spacings in each
            % Calculate point numbers and vertical position
            pc = pc + 1;
            z = z + ss_H(i)/(ss_nst(i)+1);
            % Write commands to file
            fprintf(fileID,...
                'asm_const_grid_xyz( "%d", "[%d %d %d]",  @\n',...
                pc,i_xof,0,z);
            fprintf(fileID,...
                '"Coord 0", asm_create_grid_xyz_created_ids )\n');
        end
    end
    
    % Create curves for extrusion
    fprintf(fileID,'STRING asm_line_2point_created_ids[VIRTUAL]\n');
    cc = 0; % Create curve counter
    for i = 1:pc-1
        cc = cc+1;
        fprintf(fileID,'asm_const_line_2point( "%d", "point %d",@\n',i,i);
        fprintf(fileID,'"point %d", 0, "", 50., 1,  @\n',i+1);
        fprintf(fileID,'asm_line_2point_created_ids )\n');
    end
    
    count = 0; % Counter for determintation of curve number
    zof = 0;   % Variable for z offset of eac section in vertical direction
    topmesh = 0; % Variable for creating fine mesh on top of this area
    % Extrude to form
    for i = 1:length(ss_nst)
        if i>=2; zof = sum(ss_H(1:i-1)); end
        for j = 1 : ss_nst(i)+1
            % web frame
            % Choose mesh fineness
            if section == 2 && zof <= 5000 && topmesh == 0
                mesh = 2;
            elseif topmesh == 0 && section == 2
                topmesh = 2;
                mesh = 1;
            else
                topmesh = 1;
                mesh = 1;
            end
            % Variable to get finemesh on end of section
            if section == 4 && zof <= 5000
                endmesh = 2;
            else
                endmesh = mesh;
            end
            sc = sc + 1;
            count = count + 1;
            % Extrude commands
            fprintf(fileID,...
                'STRING sgm_sweep_surface_e_created_ids[VIRTUAL]\n');
            fprintf(fileID,'sgm_const_surface_extrude( "%d",@\n',sc);
            fprintf(fileID,...
                '"<0 %d 0>", 1., 0., "[0 0 0]", "Coord 0",  @\n',g_wss);
            fprintf(fileID,...
                '"Curve %d", sgm_sweep_surface_e_created_ids )\n',count);
            % Breake web frame for easier meshing
            coord = [i_xof, (g_wss-650)/2, zof+(j-1)/(ss_nst(i)+1)*ss_H(i);
                i_xof,g_wss-(g_wss-650)/2 ,zof+(j-1)/(ss_nst(i)+1)*ss_H(i);
                i_xof, (g_wss-650)/2,      zof+j/(ss_nst(i)+1)*ss_H(i);
                i_xof, g_wss-(g_wss-650)/2,zof+j/(ss_nst(i)+1)*ss_H(i)];
            sc = prep_string(fileID,coord,sc,1,sc);
            % Save fem data, webframes ignored if it is the first section
            if section ~=1 && b == 1;
                for k = 1:3
                    femc_sh = femc_sh + 1;
                    fem_dat_sh(femc_sh,1) = sc-k+1;
                    if (j-1)/(ss_nst(i)+1)*ss_H(i) <= 800
                        fem_dat_sh(femc_sh,2) = ss_plt_wf(2,i);
                    else
                        fem_dat_sh(femc_sh,2) = ss_plt_wf(1,i);
                    end
                    fem_dat_sh(femc_sh,3) = endmesh;
                    if j~=1
                        femc_be = femc_be +1;
                        % Surface number
                        fem_dat_be(femc_be,1) = sc-k+1; 
                        % Curve side number
                        fem_dat_be(femc_be,2) = 1;  
                        % Property number
                        fem_dat_be(femc_be,3) = ss_sti_wf(1,i);  
                        % Mesh fineness
                        fem_dat_be(femc_be,4) = endmesh; 
                    end
                end
            end
            
            sc = sc + 1;
            % inner skin
            fprintf(fileID,'sgm_const_surface_extrude( "%d",@\n',sc);
            fprintf(fileID,...
               '"<%d 0 0>", 1., 0., "[0 0 0]", "Coord 0",  @\n',i_l);
            fprintf(fileID,...
               '"Surface %d.2", sgm_sweep_surface_e_created_ids )\n',sc-3);
            femc_sh = femc_sh + 1;
            fem_dat_sh(femc_sh,1) =  sc;
            fem_dat_sh(femc_sh,2) = ss_plt_is(i);
            fem_dat_sh(femc_sh,3) = mesh;
            % Save boundary condition data if these apply
            if section == 1 && b == 1
                bcc = bcc + 1;
                bc(bcc,1) = sc;
                bc(bcc,2) = 4;
                bc(bcc,3) = 1;
            elseif section == 3 && b == 3
                bcc = bcc + 1;
                bc(bcc,1) = sc;
                bc(bcc,2) = 2;
                bc(bcc,3) = 1;
            end
            % Save FEM data
            if j~=1
                femc_be = femc_be +1;
                fem_dat_be(femc_be,1) = sc; % Surface number
                fem_dat_be(femc_be,2) = 1;  % Curve side number
                fem_dat_be(femc_be,3) = ss_sti_is(i);  % Property number
                fem_dat_be(femc_be,4) = mesh; % Mesh fineness
            end
            
            % Breaking inner top skin where it meets decksection girder,
            % for easier meshing
            if i == length(ss_nst) &&...
                    (j)*ss_H(i)/(ss_nst(i)+1) >= ss_H(i)-550 && lb == 0
                
                lb = 1; % Store breakage
                % Consturct points and line for breaking
                fprintf(fileID,'asm_const_grid_xyz( "%d",@\n',3001);
                fprintf(fileID,'"[%d %d %d]", "Coord 0",  @\n'...
                    ,i_xof,0,zof+ss_H(i)-550);
                fprintf(fileID,'asm_create_grid_xyz_created_ids )\n');
                fprintf(fileID,'asm_const_grid_xyz( "%d",@\n',3002);
                fprintf(fileID,'"[%d %d %d]", "Coord 0",  @\n',...
                    i_xof+i_l,0,zof+ss_H(i)-550);
                fprintf(fileID,'asm_create_grid_xyz_created_ids )\n');
                fprintf(fileID,...
                    'STRING asm_line_2point_created_ids[VIRTUAL]\n');
                fprintf(fileID,'asm_const_line_2point( "3001",@\n');
                fprintf(fileID,...
                    '"point 3002", "point 3001", 0, "", 50., 1,  @\n');
                fprintf(fileID,'asm_line_2point_created_ids )\n');
                % Break surface
                sc = sc+1;
                fprintf(fileID,...
                    'STRING sgm_surface_break_c_created_ids[VIRTUAL]\n');
                fprintf(fileID,'sgm_edit_surface_break_v1( "%d",@\n',sc);
                fprintf(fileID,'"Surface %d", FALSE, 3, 0, 0.,@\n',sc-1);
                fprintf(fileID,'"", "", "Curve 3001", @\n');
                fprintf(fileID,'sgm_surface_break_c_created_ids )\n');
                fprintf(fileID,...
                    'STRING asm_delete_surface_deleted_ids[VIRTUAL])\n');
                % Delete old surface
                fprintf(fileID,'asm_delete_surface(@\n');
                fprintf(fileID,'"Surface %d", @\n',sc-1);
                fprintf(fileID,'asm_delete_surface_deleted_ids )\n');
                % Renumber new surface
                fprintf(fileID,...
                    'STRING sgm_renum_surface_new_ids[VIRTUAL]\n');
                fprintf(fileID,'sgm_renumber( 1, "surface", @\n');
                fprintf(fileID,'"%d", "Surface %d",  @\n',sc-1,sc+1);
                fprintf(fileID,'sgm_renum_surface_new_ids )\n');
                % Store FEM data
                femc_sh = femc_sh + 1;
                fem_dat_sh(femc_sh,1) =  sc;
                fem_dat_sh(femc_sh,2) = ss_plt_is(i);
                fem_dat_sh(femc_sh,3) = mesh;
                % Deletion of break curves
                fprintf(fileID,...
                    'STRING asm_delete_curve_deleted_ids[VIRTUAL]\n');
                fprintf(fileID,'asm_delete_curve( "Curve 3001",@\n');
                fprintf(fileID,'asm_delete_curve_deleted_ids )\n');
                % Deletion of break points
                fprintf(fileID,...
                    'STRING asm_delete_point_deleted_ids[VIRTUAL]\n');
                fprintf(fileID,'asm_delete_point( "Point 2001:2002",@\n');
                fprintf(fileID,'asm_delete_point_deleted_ids )\n');
                % Store boundary conditions if applicable
                if section == 1 && b == 1
                    bcc = bcc + 1;
                    bc(bcc,:) = [sc 4 1];
                    bcc = bcc + 1;
                    bc(bcc,:) = [sc-1 4 1];
                elseif section == 3 && b == 3
                    bcc = bcc + 1;
                    bc(bcc,:) = [sc 2 1];
                    bcc = bcc + 1;
                    bc(bcc,:) = [sc-1 2 1];
                end
            end
            
            % Extrude outer skin
            sc = sc + 1;
            fprintf(fileID,...
                'STRING sgm_sweep_surface_e_created_ids[VIRTUAL]\n');
            fprintf(fileID,'sgm_const_surface_extrude( @\n');
            fprintf(fileID,'"%d", "<%d 0 0>",@\n',sc,i_l);
            fprintf(fileID,'1., 0., "[0 0 0]", "Coord 0",@\n');  
            if lb == 0 || lb == 2
                fprintf(fileID,'"Surface %d.4", @\n',sc-3);
                fprintf(fileID,'sgm_sweep_surface_e_created_ids )\n');
            else
                fprintf(fileID,'"Surface %d.4", @\n',sc-4);
                fprintf(fileID,'sgm_sweep_surface_e_created_ids )\n');
                lb = 2;
            end
            % Store FEM and BC data
            femc_sh = femc_sh + 1;
            fem_dat_sh(femc_sh,1) = sc;
            fem_dat_sh(femc_sh,2) = ss_plt_os(i);
            fem_dat_sh(femc_sh,3) = mesh;
            if section == 1 && b == 1
                bcc = bcc + 1;
                bc(bcc,1) = sc;
                bc(bcc,2) = 4;
                bc(bcc,3) = 1;
            elseif section == 3 && b == 3
                bcc = bcc + 1;
                bc(bcc,1) = sc;
                bc(bcc,2) = 2;
                bc(bcc,3) = 1;
            end
            if j~=1
                femc_be = femc_be +1;
                fem_dat_be(femc_be,1) = sc; % Surface number
                fem_dat_be(femc_be,2) = 1;  % Curve side number
                fem_dat_be(femc_be,3) = ss_sti_os(i);  % Property number
                fem_dat_be(femc_be,4) = mesh;
            end
            
            % Extrude stringers
            if j == 1
                smesh = mesh;
                if topmesh == 2
                    smesh = topmesh;
                end
                sc = sc + 1;
                fprintf(fileID,'sgm_const_surface_extrude( @\n');
                fprintf(fileID,'"%d", "<0 %d 0>", 1., 0.,@\n',sc,g_wss);
                fprintf(fileID,'"[0 0 0]", "Coord 0",  @\n');
                fprintf(fileID,'"Surface %d.1", @\n',sc-1);
                fprintf(fileID,'sgm_sweep_surface_e_created_ids )\n');
                if b == 2
                    femc_sh = femc_sh + 1;
                    fem_dat_sh(femc_sh,:) =  [sc ss_plt_str(2,i) smesh];
                else
                    femc_sh = femc_sh + 1;
                    fem_dat_sh(femc_sh,:) =  [sc ss_plt_str(1,i) smesh];
                end
                % Breake stringers and tank top for stiffeners
                coord =  [  i_xof+i_l, (g_wss-650)/2, zof;
                    i_xof+i_l,g_wss-(g_wss-650)/2 ,       zof
                    i_xof, (g_wss-650)/2, zof;
                    i_xof, g_wss-(g_wss-650)/2,       zof];
                sc = prep_string(fileID,coord,sc,2,sc);
                % Store FEM and BC data where applicable
                femc_be = femc_be +1;
                fem_dat_be(femc_be,:) = [sc 2 ss_sti_str(i) smesh];
                femc_be = femc_be +1;
                fem_dat_be(femc_be,:) = [sc 4 ss_sti_str(i) smesh];
                if b == 2
                    femc_sh = femc_sh + 1;
                    fem_dat_sh(femc_sh,:) =  [sc ss_plt_str(2,i) smesh];
                    femc_sh = femc_sh + 1;
                    fem_dat_sh(femc_sh,:) =  [sc-1 ss_plt_str(2,i) smesh];
                else
                    femc_sh = femc_sh + 1;
                    fem_dat_sh(femc_sh,:) =  [sc ss_plt_str(1,i) smesh];
                    femc_sh = femc_sh + 1;
                    fem_dat_sh(femc_sh,:) =  [sc-1 ss_plt_str(1,i) smesh];
                end
                if section == 1 && b == 1
                    bcc = bcc + 1;
                    bc(bcc,:) = [sc 3 1];
                    bcc = bcc + 1;
                    bc(bcc,:) = [sc-1 1 1];
                    bcc = bcc + 1;
                    bc(bcc,:) = [sc-2 1 1];   
                elseif section == 3 && b == 3
                    bcc = bcc + 1;
                    bc(bcc,:) = [sc 1 1];
                    bcc = bcc + 1;
                    bc(bcc,:) = [sc-1 3 1];
                    bcc = bcc + 1;
                    bc(bcc,:) = [sc-2 3 1];
                end
            end
        end
    end
    
    % Extrude deck on sidesection
    sc = sc + 1;
    fprintf(fileID,'sgm_const_surface_extrude( "%d", "<0 %d @\n',sc,g_wss);
    fprintf(fileID,'0>", 1., 0., "[0 0 0]", "Coord 0",  @\n');
    fprintf(fileID,...
        '"Surface %d.3", sgm_sweep_surface_e_created_ids )\n',sc-1);
    zof = sum(ss_H);
    femc_sh = femc_sh + 1;
    fem_dat_sh(femc_sh,:) =  [sc ss_plt_str(1,length(ss_plt_str)) 1];
    % Break deck for easier meshing
    coord =  [  i_xof+i_l, (g_wss-650)/2, zof;
        i_xof+i_l,g_wss-(g_wss-650)/2 ,       zof
        i_xof, (g_wss-650)/2, zof;
        i_xof, g_wss-(g_wss-650)/2,       zof];
    sc = prep_string(fileID,coord,sc,2,sc);
    femc_sh = femc_sh + 1;
    fem_dat_sh(femc_sh,:) =  [sc ss_plt_str(1,length(ss_plt_str)) 1];
    femc_sh = femc_sh + 1;
    fem_dat_sh(femc_sh,:) =  [sc-1 ss_plt_str(1,length(ss_plt_str)) 1];
    if section == 1 && b == 1
        bcc = bcc + 1;
        bc(bcc,:) = [sc 3 1];
        bcc = bcc + 1;
        bc(bcc,:) = [sc-1 1 1];
        bcc = bcc + 1;
        bc(bcc,:) = [sc-2 1 1];
    elseif section == 3 && b == 3
        bcc = bcc + 1;
        bc(bcc,:) = [sc 1 1];
        bcc = bcc + 1;
        bc(bcc,:) = [sc-1 3 1];
        bcc = bcc + 1;
        bc(bcc,:) = [sc-2 3 1];
    end
    % Delete points and curves used
    fprintf(fileID,'STRING asm_delete_point_deleted_ids[VIRTUAL]\n');
    fprintf(fileID,...
     'asm_delete_point( "Point 1:4000", asm_delete_any_deleted_ids )\n');
    fprintf(fileID,...
     'STRING asm_delete_curve_deleted_ids[VIRTUAL]\n');
    fprintf(fileID,...
     'asm_delete_curve( "Curve 1:1000", asm_delete_curve_deleted_ids )\n');
end
end
